@@ -26,21 +26,19 @@
  * exception statement from your version.
  */
 
-#ifndef BITTORRENT_TORRENTINFO_H
-#define BITTORRENT_TORRENTINFO_H
+#pragma once
 
 #include <libtorrent/torrent_info.hpp>
-#include <libtorrent/version.hpp>
 
 #include <QCoreApplication>
-#include <QVector>
+#include <QtContainerFwd>
 
 #include "base/indexrange.h"
+#include "torrentcontentlayout.h"
 
 class QByteArray;
 class QDateTime;
 class QString;
-class QStringList;
 class QUrl;
 
 namespace BitTorrent
@@ -53,15 +51,7 @@ namespace BitTorrent
         Q_DECLARE_TR_FUNCTIONS(TorrentInfo)
 
     public:
-#if (LIBTORRENT_VERSION_NUM < 10200)
-        using NativeConstPtr = boost::shared_ptr<const lt::torrent_info>;
-        using NativePtr = boost::shared_ptr<lt::torrent_info>;
-#else
-        using NativeConstPtr = std::shared_ptr<const lt::torrent_info>;
-        using NativePtr = std::shared_ptr<lt::torrent_info>;
-#endif
-
-        explicit TorrentInfo(NativeConstPtr nativeInfo = {});
+        explicit TorrentInfo(std::shared_ptr<const lt::torrent_info> nativeInfo = {});
         TorrentInfo(const TorrentInfo &other);
 
         static TorrentInfo load(const QByteArray &data, QString *error = nullptr) noexcept;
@@ -105,15 +95,17 @@ namespace BitTorrent
 
         QString rootFolder() const;
         bool hasRootFolder() const;
-        void stripRootFolder();
+        void setContentLayout(TorrentContentLayout layout);
 
-        NativePtr nativeInfo() const;
+        std::shared_ptr<lt::torrent_info> nativeInfo() const;
 
     private:
         // returns file index or -1 if fileName is not found
         int fileIndex(const QString &fileName) const;
-        NativePtr m_nativeInfo;
+        void stripRootFolder();
+        void addRootFolder();
+        TorrentContentLayout defaultContentLayout() const;
+
+        std::shared_ptr<lt::torrent_info> m_nativeInfo;
     };
 }
-
-#endif // BITTORRENT_TORRENTINFO_H
