@@ -41,6 +41,7 @@
 #include <QSet>
 #include <QShortcut>
 #include <QTableView>
+#include <QVector>
 #include <QWheelEvent>
 
 #include "base/bittorrent/infohash.h"
@@ -90,7 +91,8 @@ namespace
         if (!torrent->hasMetadata())
             return false;
 
-        for (int i = 0; i < torrent->filesCount(); ++i) {
+        for (int i = 0; i < torrent->filesCount(); ++i)
+        {
             if (Utils::Misc::isPreviewable(Utils::Fs::fileExtension(torrent->fileName(i))))
                 return true;
         }
@@ -159,7 +161,8 @@ TransferListWidget::TransferListWidget(QWidget *parent, MainWindow *mainWindow)
     header()->setStretchLastSection(false);
 
     // Default hidden columns
-    if (!columnLoaded) {
+    if (!columnLoaded)
+    {
         setColumnHidden(TransferListModel::TR_ADD_DATE, true);
         setColumnHidden(TransferListModel::TR_SEED_DATE, true);
         setColumnHidden(TransferListModel::TR_UPLIMIT, true);
@@ -181,8 +184,10 @@ TransferListWidget::TransferListWidget(QWidget *parent, MainWindow *mainWindow)
 
     //Ensure that at least one column is visible at all times
     bool atLeastOne = false;
-    for (int i = 0; i < TransferListModel::NB_COLUMNS; ++i) {
-        if (!isColumnHidden(i)) {
+    for (int i = 0; i < TransferListModel::NB_COLUMNS; ++i)
+    {
+        if (!isColumnHidden(i))
+        {
             atLeastOne = true;
             break;
         }
@@ -240,197 +245,6 @@ TransferListModel *TransferListWidget::getSourceModel() const
     return m_listModel;
 }
 
-QColor TransferListWidget::unknownStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::Unknown);
-}
-
-QColor TransferListWidget::forcedDownloadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::ForcedDownloading);
-}
-
-QColor TransferListWidget::downloadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::Downloading);
-}
-
-QColor TransferListWidget::downloadingMetadataStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::DownloadingMetadata);
-}
-
-QColor TransferListWidget::allocatingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::Allocating);
-}
-
-QColor TransferListWidget::stalledDownloadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::StalledDownloading);
-}
-
-QColor TransferListWidget::forcedUploadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::ForcedUploading);
-}
-
-QColor TransferListWidget::uploadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::Uploading);
-}
-
-QColor TransferListWidget::stalledUploadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::StalledUploading);
-}
-
-QColor TransferListWidget::checkingResumeDataStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::CheckingResumeData);
-}
-
-QColor TransferListWidget::queuedDownloadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::QueuedDownloading);
-}
-
-QColor TransferListWidget::queuedUploadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::QueuedUploading);
-}
-
-QColor TransferListWidget::checkingUploadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::CheckingUploading);
-}
-
-QColor TransferListWidget::checkingDownloadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::CheckingDownloading);
-}
-
-QColor TransferListWidget::pausedDownloadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::PausedDownloading);
-}
-
-QColor TransferListWidget::pausedUploadingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::PausedUploading);
-}
-
-QColor TransferListWidget::movingStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::Moving);
-}
-
-QColor TransferListWidget::missingFilesStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::MissingFiles);
-}
-
-QColor TransferListWidget::errorStateForeground() const
-{
-    return m_listModel->stateForeground(BitTorrent::TorrentState::Error);
-}
-
-void TransferListWidget::setUnknownStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::Unknown, color);
-}
-
-void TransferListWidget::setForcedDownloadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::ForcedDownloading, color);
-}
-
-void TransferListWidget::setDownloadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::Downloading, color);
-}
-
-void TransferListWidget::setDownloadingMetadataStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::DownloadingMetadata, color);
-}
-
-void TransferListWidget::setAllocatingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::Allocating, color);
-}
-
-void TransferListWidget::setStalledDownloadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::StalledDownloading, color);
-}
-
-void TransferListWidget::setForcedUploadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::ForcedUploading, color);
-}
-
-void TransferListWidget::setUploadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::Uploading, color);
-}
-
-void TransferListWidget::setStalledUploadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::StalledUploading, color);
-}
-
-void TransferListWidget::setCheckingResumeDataStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::CheckingResumeData, color);
-}
-
-void TransferListWidget::setQueuedDownloadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::QueuedDownloading, color);
-}
-
-void TransferListWidget::setQueuedUploadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::QueuedUploading, color);
-}
-
-void TransferListWidget::setCheckingUploadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::CheckingUploading, color);
-}
-
-void TransferListWidget::setCheckingDownloadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::CheckingDownloading, color);
-}
-
-void TransferListWidget::setPausedDownloadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::PausedDownloading, color);
-}
-
-void TransferListWidget::setPausedUploadingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::PausedUploading, color);
-}
-
-void TransferListWidget::setMovingStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::Moving, color);
-}
-
-void TransferListWidget::setMissingFilesStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::MissingFiles, color);
-}
-
-void TransferListWidget::setErrorStateForeground(const QColor &color)
-{
-    m_listModel->setStateForeground(BitTorrent::TorrentState::Error, color);
-}
-
-
 void TransferListWidget::previewFile(const QString &filePath)
 {
     Utils::Gui::openPath(filePath);
@@ -466,7 +280,8 @@ void TransferListWidget::torrentDoubleClicked()
     else
         action = Preferences::instance()->getActionOnDblClOnTorrentDl();
 
-    switch (action) {
+    switch (action)
+    {
     case TOGGLE_PAUSE:
         if (torrent->isPaused())
             torrent->resume();
@@ -474,13 +289,15 @@ void TransferListWidget::torrentDoubleClicked()
             torrent->pause();
         break;
     case PREVIEW_FILE:
-        if (torrentContainsPreviewableFiles(torrent)) {
+        if (torrentContainsPreviewableFiles(torrent))
+        {
             auto *dialog = new PreviewSelectDialog(this, torrent);
             dialog->setAttribute(Qt::WA_DeleteOnClose);
             connect(dialog, &PreviewSelectDialog::readyToPreviewFile, this, &TransferListWidget::previewFile);
             dialog->show();
         }
-        else {
+        else
+        {
             openDestinationFolder(torrent);
         }
         break;
@@ -501,6 +318,17 @@ QVector<BitTorrent::TorrentHandle *> TransferListWidget::getSelectedTorrents() c
     return torrents;
 }
 
+QVector<BitTorrent::TorrentHandle *> TransferListWidget::getVisibleTorrents() const
+{
+    const int visibleTorrentsCount = m_sortFilterModel->rowCount();
+
+    QVector<BitTorrent::TorrentHandle *> torrents;
+    torrents.reserve(visibleTorrentsCount);
+    for (int i = 0; i < visibleTorrentsCount; ++i)
+        torrents << m_listModel->torrentHandle(mapToSource(m_sortFilterModel->index(i, 0)));
+    return torrents;
+}
+
 void TransferListWidget::setSelectedTorrentsLocation()
 {
     const QVector<BitTorrent::TorrentHandle *> torrents = getSelectedTorrents();
@@ -512,13 +340,8 @@ void TransferListWidget::setSelectedTorrentsLocation()
     if (newLocation.isEmpty() || !QDir(newLocation).exists()) return;
 
     // Actually move storage
-    for (BitTorrent::TorrentHandle *const torrent : torrents) {
-        Logger::instance()->addMessage(tr("Set location: moving \"%1\", from \"%2\" to \"%3\""
-            , "Set location: moving \"ubuntu_16_04.iso\", from \"/home/dir1\" to \"/home/dir2\"")
-            .arg(torrent->name(), Utils::Fs::toNativePath(torrent->savePath())
-                , Utils::Fs::toNativePath(newLocation)));
+    for (BitTorrent::TorrentHandle *const torrent : torrents)
         torrent->move(Utils::Fs::expandPathAbs(newLocation));
-    }
 }
 
 void TransferListWidget::pauseAllTorrents()
@@ -542,16 +365,13 @@ void TransferListWidget::startSelectedTorrents()
 void TransferListWidget::forceStartSelectedTorrents()
 {
     for (BitTorrent::TorrentHandle *const torrent : asConst(getSelectedTorrents()))
-        torrent->resume(true);
+        torrent->resume(BitTorrent::TorrentOperatingMode::Forced);
 }
 
 void TransferListWidget::startVisibleTorrents()
 {
-    for (int i = 0; i < m_sortFilterModel->rowCount(); ++i) {
-        BitTorrent::TorrentHandle *const torrent = m_listModel->torrentHandle(mapToSource(m_sortFilterModel->index(i, 0)));
-        if (torrent)
-            torrent->resume();
-    }
+    for (BitTorrent::TorrentHandle *const torrent : asConst(getVisibleTorrents()))
+        torrent->resume();
 }
 
 void TransferListWidget::pauseSelectedTorrents()
@@ -562,11 +382,8 @@ void TransferListWidget::pauseSelectedTorrents()
 
 void TransferListWidget::pauseVisibleTorrents()
 {
-    for (int i = 0; i < m_sortFilterModel->rowCount(); ++i) {
-        BitTorrent::TorrentHandle *const torrent = m_listModel->torrentHandle(mapToSource(m_sortFilterModel->index(i, 0)));
-        if (torrent)
-            torrent->pause();
-    }
+    for (BitTorrent::TorrentHandle *const torrent : asConst(getVisibleTorrents()))
+        torrent->pause();
 }
 
 void TransferListWidget::softDeleteSelectedTorrents()
@@ -586,38 +403,43 @@ void TransferListWidget::deleteSelectedTorrents(const bool deleteLocalFiles)
     const QVector<BitTorrent::TorrentHandle *> torrents = getSelectedTorrents();
     if (torrents.empty()) return;
 
-    if (Preferences::instance()->confirmTorrentDeletion()) {
+    if (Preferences::instance()->confirmTorrentDeletion())
+    {
         auto *dialog = new DeletionConfirmationDialog(this, torrents.size(), torrents[0]->name(), deleteLocalFiles);
         dialog->setAttribute(Qt::WA_DeleteOnClose);
-        connect(dialog, &DeletionConfirmationDialog::accepted, this, [dialog, torrents]()
+        connect(dialog, &DeletionConfirmationDialog::accepted, this, [this, dialog]()
         {
-            removeTorrents(torrents, dialog->isDeleteFileSelected());
+            // Some torrents might be removed when waiting for user input, so refetch the torrent list
+            // NOTE: this will only work when dialog is modal
+            removeTorrents(getSelectedTorrents(), dialog->isDeleteFileSelected());
         });
         dialog->open();
     }
-    else {
+    else
+    {
         removeTorrents(torrents, deleteLocalFiles);
     }
 }
 
 void TransferListWidget::deleteVisibleTorrents()
 {
-    if (m_sortFilterModel->rowCount() <= 0) return;
+    const QVector<BitTorrent::TorrentHandle *> torrents = getVisibleTorrents();
+    if (torrents.empty()) return;
 
-    QVector<BitTorrent::TorrentHandle *> torrents;
-    for (int i = 0; i < m_sortFilterModel->rowCount(); ++i)
-        torrents << m_listModel->torrentHandle(mapToSource(m_sortFilterModel->index(i, 0)));
-
-    if (Preferences::instance()->confirmTorrentDeletion()) {
+    if (Preferences::instance()->confirmTorrentDeletion())
+    {
         auto *dialog = new DeletionConfirmationDialog(this, torrents.size(), torrents[0]->name(), false);
         dialog->setAttribute(Qt::WA_DeleteOnClose);
-        connect(dialog, &DeletionConfirmationDialog::accepted, this, [dialog, torrents]()
+        connect(dialog, &DeletionConfirmationDialog::accepted, this, [this, dialog]()
         {
-            removeTorrents(torrents, dialog->isDeleteFileSelected());
+            // Some torrents might be removed when waiting for user input, so refetch the torrent list
+            // NOTE: this will only work when dialog is modal
+            removeTorrents(getVisibleTorrents(), dialog->isDeleteFileSelected());
         });
         dialog->open();
     }
-    else {
+    else
+    {
         removeTorrents(torrents, false);
     }
 }
@@ -688,15 +510,18 @@ void TransferListWidget::openSelectedTorrentsFolder() const
 #ifdef Q_OS_MACOS
     // On macOS you expect both the files and folders to be opened in their parent
     // folders prehilighted for opening, so we use a custom method.
-    for (BitTorrent::TorrentHandle *const torrent : asConst(getSelectedTorrents())) {
+    for (BitTorrent::TorrentHandle *const torrent : asConst(getSelectedTorrents()))
+    {
         QString path = torrent->contentPath(true);
         pathsList.insert(path);
     }
     MacUtils::openFiles(pathsList);
 #else
-    for (BitTorrent::TorrentHandle *const torrent : asConst(getSelectedTorrents())) {
+    for (BitTorrent::TorrentHandle *const torrent : asConst(getSelectedTorrents()))
+    {
         QString path = torrent->contentPath(true);
-        if (!pathsList.contains(path)) {
+        if (!pathsList.contains(path))
+        {
             if (torrent->filesCount() == 1)
                 Utils::Gui::openFolderSelect(path);
             else
@@ -709,14 +534,17 @@ void TransferListWidget::openSelectedTorrentsFolder() const
 
 void TransferListWidget::previewSelectedTorrents()
 {
-    for (const BitTorrent::TorrentHandle *torrent : asConst(getSelectedTorrents())) {
-        if (torrentContainsPreviewableFiles(torrent)) {
+    for (const BitTorrent::TorrentHandle *torrent : asConst(getSelectedTorrents()))
+    {
+        if (torrentContainsPreviewableFiles(torrent))
+        {
             auto *dialog = new PreviewSelectDialog(this, torrent);
             dialog->setAttribute(Qt::WA_DeleteOnClose);
             connect(dialog, &PreviewSelectDialog::readyToPreviewFile, this, &TransferListWidget::previewFile);
             dialog->show();
         }
-        else {
+        else
+        {
             QMessageBox::critical(this, tr("Unable to preview"), tr("The selected torrent \"%1\" does not contain previewable files")
                 .arg(torrent->name()));
         }
@@ -726,7 +554,8 @@ void TransferListWidget::previewSelectedTorrents()
 void TransferListWidget::setDlLimitSelectedTorrents()
 {
     QVector<BitTorrent::TorrentHandle *> torrentsList;
-    for (BitTorrent::TorrentHandle *const torrent : asConst(getSelectedTorrents())) {
+    for (BitTorrent::TorrentHandle *const torrent : asConst(getSelectedTorrents()))
+    {
         if (torrent->isSeed())
             continue;
         torrentsList += torrent;
@@ -734,8 +563,10 @@ void TransferListWidget::setDlLimitSelectedTorrents()
     if (torrentsList.empty()) return;
 
     int oldLimit = torrentsList.first()->downloadLimit();
-    for (BitTorrent::TorrentHandle *const torrent : asConst(torrentsList)) {
-        if (torrent->downloadLimit() != oldLimit) {
+    for (BitTorrent::TorrentHandle *const torrent : asConst(torrentsList))
+    {
+        if (torrent->downloadLimit() != oldLimit)
+        {
             oldLimit = -1;
             break;
         }
@@ -747,7 +578,8 @@ void TransferListWidget::setDlLimitSelectedTorrents()
                 , BitTorrent::Session::instance()->globalDownloadSpeedLimit());
     if (!ok) return;
 
-    for (BitTorrent::TorrentHandle *const torrent : asConst(torrentsList)) {
+    for (BitTorrent::TorrentHandle *const torrent : asConst(torrentsList))
+    {
         qDebug("Applying download speed limit of %ld Kb/s to torrent %s", (newLimit / 1024l), qUtf8Printable(torrent->hash()));
         torrent->setDownloadLimit(newLimit);
     }
@@ -759,8 +591,10 @@ void TransferListWidget::setUpLimitSelectedTorrents()
     if (torrentsList.empty()) return;
 
     int oldLimit = torrentsList.first()->uploadLimit();
-    for (BitTorrent::TorrentHandle *const torrent : asConst(torrentsList)) {
-        if (torrent->uploadLimit() != oldLimit) {
+    for (BitTorrent::TorrentHandle *const torrent : asConst(torrentsList))
+    {
+        if (torrent->uploadLimit() != oldLimit)
+        {
             oldLimit = -1;
             break;
         }
@@ -772,7 +606,8 @@ void TransferListWidget::setUpLimitSelectedTorrents()
                 , BitTorrent::Session::instance()->globalUploadSpeedLimit());
     if (!ok) return;
 
-    for (BitTorrent::TorrentHandle *const torrent : asConst(torrentsList)) {
+    for (BitTorrent::TorrentHandle *const torrent : asConst(torrentsList))
+    {
         qDebug("Applying upload speed limit of %ld Kb/s to torrent %s", (newLimit / 1024l), qUtf8Printable(torrent->hash()));
         torrent->setUploadLimit(newLimit);
     }
@@ -801,7 +636,8 @@ void TransferListWidget::setMaxRatioSelectedTorrents()
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     connect(dialog, &QDialog::accepted, this, [dialog, torrents]()
     {
-        for (BitTorrent::TorrentHandle *const torrent : torrents) {
+        for (BitTorrent::TorrentHandle *const torrent : torrents)
+        {
             const qreal ratio = (dialog->useDefault()
                 ? BitTorrent::TorrentHandle::USE_GLOBAL_RATIO : dialog->ratio());
             torrent->setRatioLimit(ratio);
@@ -816,7 +652,8 @@ void TransferListWidget::setMaxRatioSelectedTorrents()
 
 void TransferListWidget::recheckSelectedTorrents()
 {
-    if (Preferences::instance()->confirmTorrentRecheck()) {
+    if (Preferences::instance()->confirmTorrentRecheck())
+    {
         QMessageBox::StandardButton ret = QMessageBox::question(this, tr("Recheck confirmation"), tr("Are you sure you want to recheck the selected torrent(s)?"), QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
         if (ret != QMessageBox::Yes) return;
     }
@@ -838,7 +675,8 @@ void TransferListWidget::displayDLHoSMenu(const QPoint&)
     menu->setAttribute(Qt::WA_DeleteOnClose);
     menu->setTitle(tr("Column visibility"));
 
-    for (int i = 0; i < m_listModel->columnCount(); ++i) {
+    for (int i = 0; i < m_listModel->columnCount(); ++i)
+    {
         if (!BitTorrent::Session::instance()->isQueueingSystemEnabled() && (i == TransferListModel::TR_QUEUE_POSITION))
             continue;
 
@@ -851,7 +689,8 @@ void TransferListWidget::displayDLHoSMenu(const QPoint&)
     connect(menu, &QMenu::triggered, this, [this](const QAction *action)
     {
         int visibleCols = 0;
-        for (int i = 0; i < TransferListModel::NB_COLUMNS; ++i) {
+        for (int i = 0; i < TransferListModel::NB_COLUMNS; ++i)
+        {
             if (!isColumnHidden(i))
                 ++visibleCols;
 
@@ -877,7 +716,8 @@ void TransferListWidget::displayDLHoSMenu(const QPoint&)
 
 void TransferListWidget::setSelectedTorrentsSuperSeeding(const bool enabled) const
 {
-    for (BitTorrent::TorrentHandle *const torrent : asConst(getSelectedTorrents())) {
+    for (BitTorrent::TorrentHandle *const torrent : asConst(getSelectedTorrents()))
+    {
         if (torrent->hasMetadata())
             torrent->setSuperSeeding(enabled);
     }
@@ -920,10 +760,12 @@ void TransferListWidget::editTorrentTrackers()
     const QVector<BitTorrent::TorrentHandle *> torrents = getSelectedTorrents();
     QVector<BitTorrent::TrackerEntry> commonTrackers;
 
-    if (!torrents.empty()) {
+    if (!torrents.empty())
+    {
         commonTrackers = torrents[0]->trackers();
 
-        for (const BitTorrent::TorrentHandle *torrent : torrents) {
+        for (const BitTorrent::TorrentHandle *torrent : torrents)
+        {
             QSet<BitTorrent::TrackerEntry> trackerSet;
 
             for (const BitTorrent::TrackerEntry &entry : asConst(torrent->trackers()))
@@ -961,7 +803,8 @@ QStringList TransferListWidget::askTagsForSelection(const QString &dialogTitle)
 {
     QStringList tags;
     bool invalid = true;
-    while (invalid) {
+    while (invalid)
+    {
         bool ok = false;
         invalid = false;
         const QString tagsInput = AutoExpandableDialog::getText(
@@ -969,9 +812,11 @@ QStringList TransferListWidget::askTagsForSelection(const QString &dialogTitle)
         if (!ok || tagsInput.isEmpty())
             return {};
         tags = tagsInput.split(',', QString::SkipEmptyParts);
-        for (QString &tag : tags) {
+        for (QString &tag : tags)
+        {
             tag = tag.trimmed();
-            if (!BitTorrent::Session::isValidTag(tag)) {
+            if (!BitTorrent::Session::isValidTag(tag))
+            {
                 QMessageBox::warning(this, tr("Invalid tag")
                                      , tr("Tag name: '%1' is invalid").arg(tag));
                 invalid = true;
@@ -983,7 +828,8 @@ QStringList TransferListWidget::askTagsForSelection(const QString &dialogTitle)
 
 void TransferListWidget::applyToSelectedTorrents(const std::function<void (BitTorrent::TorrentHandle *const)> &fn)
 {
-    for (const QModelIndex &index : asConst(selectionModel()->selectedRows())) {
+    for (const QModelIndex &index : asConst(selectionModel()->selectedRows()))
+    {
         BitTorrent::TorrentHandle *const torrent = m_listModel->torrentHandle(mapToSource(index));
         Q_ASSERT(torrent);
         fn(torrent);
@@ -1002,7 +848,8 @@ void TransferListWidget::renameSelectedTorrent()
     // Ask for a new Name
     bool ok = false;
     QString name = AutoExpandableDialog::getText(this, tr("Rename"), tr("New name:"), QLineEdit::Normal, torrent->name(), &ok);
-    if (ok && !name.isEmpty()) {
+    if (ok && !name.isEmpty())
+    {
         name.replace(QRegularExpression("\r?\n|\r"), " ");
         // Rename the torrent
         m_listModel->setData(mi, name, Qt::DisplayRole);
@@ -1050,7 +897,7 @@ void TransferListWidget::displayListMenu(const QPoint &)
     connect(actionDelete, &QAction::triggered, this, &TransferListWidget::softDeleteSelectedTorrents);
     auto *actionPreviewFile = new QAction(UIThemeManager::instance()->getIcon("view-preview"), tr("Preview file..."), listMenu);
     connect(actionPreviewFile, &QAction::triggered, this, &TransferListWidget::previewSelectedTorrents);
-    auto *actionSetMaxRatio = new QAction(QIcon(QLatin1String(":/icons/skin/ratio.svg")), tr("Limit share ratio..."), listMenu);
+    auto *actionSetMaxRatio = new QAction(UIThemeManager::instance()->getIcon(QLatin1String("ratio")), tr("Limit share ratio..."), listMenu);
     connect(actionSetMaxRatio, &QAction::triggered, this, &TransferListWidget::setMaxRatioSelectedTorrents);
     auto *actionSetUploadLimit = new QAction(UIThemeManager::instance()->getIcon("kt-set-max-upload-speed"), tr("Limit upload rate..."), listMenu);
     connect(actionSetUploadLimit, &QAction::triggered, this, &TransferListWidget::setUpLimitSelectedTorrents);
@@ -1108,7 +955,8 @@ void TransferListWidget::displayListMenu(const QPoint &)
     QSet<QString> tagsInAny;
     QSet<QString> tagsInAll;
 
-    for (const QModelIndex &index : selectedIndexes) {
+    for (const QModelIndex &index : selectedIndexes)
+    {
         // Get the file name
         // Get handle and pause the torrent
         const BitTorrent::TorrentHandle *torrent = m_listModel->torrentHandle(mapToSource(index));
@@ -1121,11 +969,13 @@ void TransferListWidget::displayListMenu(const QPoint &)
 
         tagsInAny.unite(torrent->tags());
 
-        if (first) {
+        if (first)
+        {
             firstAutoTMM = torrent->isAutoTMMEnabled();
             tagsInAll = torrent->tags();
         }
-        else {
+        else
+        {
             tagsInAll.intersect(torrent->tags());
         }
 
@@ -1134,35 +984,51 @@ void TransferListWidget::displayListMenu(const QPoint &)
 
         if (torrent->hasMetadata())
             oneHasMetadata = true;
-        if (!torrent->isSeed()) {
+        if (!torrent->isSeed())
+        {
             oneNotSeed = true;
-            if (first) {
+            if (first)
+            {
                 sequentialDownloadMode = torrent->isSequentialDownload();
                 prioritizeFirstLast = torrent->hasFirstLastPiecePriority();
             }
-            else {
+            else
+            {
                 if (sequentialDownloadMode != torrent->isSequentialDownload())
                     allSameSequentialDownloadMode = false;
                 if (prioritizeFirstLast != torrent->hasFirstLastPiecePriority())
                     allSamePrioFirstlast = false;
             }
         }
-        else {
-            if (!oneNotSeed && allSameSuperSeeding && torrent->hasMetadata()) {
+        else
+        {
+            if (!oneNotSeed && allSameSuperSeeding && torrent->hasMetadata())
+            {
                 if (first)
                     superSeedingMode = torrent->superSeeding();
                 else if (superSeedingMode != torrent->superSeeding())
                     allSameSuperSeeding = false;
             }
         }
+
         if (!torrent->isForced())
             needsForce = true;
         else
             needsStart = true;
+
         if (torrent->isPaused())
             needsStart = true;
         else
             needsPause = true;
+
+        if (torrent->isErrored() || torrent->hasMissingFiles())
+        {
+            // If torrent is in "errored" or "missing files" state
+            // it cannot keep further processing until you restart it.
+            needsStart = true;
+            needsForce = true;
+        }
+
         if (torrent->hasMetadata())
             needsPreview = true;
 
@@ -1170,7 +1036,8 @@ void TransferListWidget::displayListMenu(const QPoint &)
 
         if (oneHasMetadata && oneNotSeed && !allSameSequentialDownloadMode
             && !allSamePrioFirstlast && !allSameSuperSeeding && !allSameCategory
-            && needsStart && needsForce && needsPause && needsPreview && !allSameAutoTMM) {
+            && needsStart && needsForce && needsPause && needsPreview && !allSameAutoTMM)
+            {
             break;
         }
     }
@@ -1203,11 +1070,13 @@ void TransferListWidget::displayListMenu(const QPoint &)
 
     categoryMenu->addSeparator();
 
-    for (const QString &category : asConst(categories)) {
+    for (const QString &category : asConst(categories))
+    {
         const QString escapedCategory = QString(category).replace('&', "&&");  // avoid '&' becomes accelerator key
 
         QAction *cat = new QAction(UIThemeManager::instance()->getIcon("inode-directory"), escapedCategory, categoryMenu);
-        if (allSameCategory && (category == firstCategory)) {
+        if (allSameCategory && (category == firstCategory))
+        {
             cat->setCheckable(true);
             cat->setChecked(true);
         }
@@ -1236,7 +1105,8 @@ void TransferListWidget::displayListMenu(const QPoint &)
 
     tagsMenu->addSeparator();
 
-    for (const QString &tag : asConst(tags)) {
+    for (const QString &tag : asConst(tags))
+    {
         auto *action = new TriStateAction(tag, tagsMenu);
         action->setCloseOnTriggered(false);
 
@@ -1266,7 +1136,8 @@ void TransferListWidget::displayListMenu(const QPoint &)
         listMenu->addAction(actionSetDownloadLimit);
     listMenu->addAction(actionSetUploadLimit);
     listMenu->addAction(actionSetMaxRatio);
-    if (!oneNotSeed && oneHasMetadata) {
+    if (!oneNotSeed && oneHasMetadata)
+    {
         actionSuperSeedingMode->setCheckState(allSameSuperSeeding
             ? (superSeedingMode ? Qt::Checked : Qt::Unchecked)
             : Qt::PartiallyChecked);
@@ -1274,11 +1145,13 @@ void TransferListWidget::displayListMenu(const QPoint &)
     }
     listMenu->addSeparator();
     bool addedPreviewAction = false;
-    if (needsPreview) {
+    if (needsPreview)
+    {
         listMenu->addAction(actionPreviewFile);
         addedPreviewAction = true;
     }
-    if (oneNotSeed) {
+    if (oneNotSeed)
+    {
         actionSequentialDownload->setCheckState(allSameSequentialDownloadMode
             ? (sequentialDownloadMode ? Qt::Checked : Qt::Unchecked)
             : Qt::PartiallyChecked);
@@ -1294,13 +1167,15 @@ void TransferListWidget::displayListMenu(const QPoint &)
 
     if (addedPreviewAction)
         listMenu->addSeparator();
-    if (oneHasMetadata) {
+    if (oneHasMetadata)
+    {
         listMenu->addAction(actionForceRecheck);
         listMenu->addAction(actionForceReannounce);
         listMenu->addSeparator();
     }
     listMenu->addAction(actionOpenDestinationFolder);
-    if (BitTorrent::Session::instance()->isQueueingSystemEnabled() && oneNotSeed) {
+    if (BitTorrent::Session::instance()->isQueueingSystemEnabled() && oneNotSeed)
+    {
         listMenu->addSeparator();
         QMenu *queueMenu = listMenu->addMenu(tr("Queue"));
         queueMenu->addAction(actionTopQueuePos);
@@ -1322,7 +1197,8 @@ void TransferListWidget::currentChanged(const QModelIndex &current, const QModel
 {
     qDebug("CURRENT CHANGED");
     BitTorrent::TorrentHandle *torrent = nullptr;
-    if (current.isValid()) {
+    if (current.isValid())
+    {
         torrent = m_listModel->torrentHandle(mapToSource(current));
         // Scroll Fix
         scrollTo(current);
@@ -1351,7 +1227,7 @@ void TransferListWidget::applyTrackerFilterAll()
     m_sortFilterModel->disableTrackerFilter();
 }
 
-void TransferListWidget::applyTrackerFilter(const QStringList &hashes)
+void TransferListWidget::applyTrackerFilter(const QSet<BitTorrent::InfoHash> &hashes)
 {
     m_sortFilterModel->setTrackerFilter(hashes);
 }
@@ -1367,7 +1243,8 @@ void TransferListWidget::applyStatusFilter(int f)
 {
     m_sortFilterModel->setStatusFilter(static_cast<TorrentFilter::Type>(f));
     // Select first item if nothing is selected
-    if (selectionModel()->selectedRows(0).empty() && (m_sortFilterModel->rowCount() > 0)) {
+    if (selectionModel()->selectedRows(0).empty() && (m_sortFilterModel->rowCount() > 0))
+    {
         qDebug("Nothing is selected, selecting first row: %s", qUtf8Printable(m_sortFilterModel->index(0, TransferListModel::TR_NAME).data().toString()));
         selectionModel()->setCurrentIndex(m_sortFilterModel->index(0, TransferListModel::TR_NAME), QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
     }
@@ -1385,11 +1262,19 @@ bool TransferListWidget::loadSettings()
 
 void TransferListWidget::wheelEvent(QWheelEvent *event)
 {
-    if (event->modifiers() & Qt::ShiftModifier) {
+    if (event->modifiers() & Qt::ShiftModifier)
+    {
         // Shift + scroll = horizontal scroll
         event->accept();
 
-        QWheelEvent scrollHEvent(event->pos(), event->globalPos(), event->delta(), event->buttons(), event->modifiers(), Qt::Horizontal);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+        QWheelEvent scrollHEvent(event->position(), event->globalPosition()
+            , event->pixelDelta(), event->angleDelta().transposed(), event->buttons()
+            , event->modifiers(), event->phase(), event->inverted(), event->source());
+#else
+        QWheelEvent scrollHEvent(event->pos(), event->globalPos()
+            , event->delta(), event->buttons(), event->modifiers(), Qt::Horizontal);
+#endif
         QTreeView::wheelEvent(&scrollHEvent);
         return;
     }
