@@ -82,6 +82,16 @@ window.qBittorrent.Download = (function() {
                 else {
                     $('autoTMM').selectedIndex = 0;
                 }
+
+                if (pref.torrent_content_layout === "Subfolder") {
+                    $('contentLayout').selectedIndex = 1;
+                }
+                else if (pref.torrent_content_layout === "NoSubfolder") {
+                    $('contentLayout').selectedIndex = 2;
+                }
+                else {
+                    $('contentLayout').selectedIndex = 0;
+                }
             }
         }).send();
     };
